@@ -1,7 +1,7 @@
-from ._descriptor import Descriptor
-from ._typed import Typed
-from ._broadtypes import *
-from ._types import Integer, Float, String, List, Mapping
+from .descriptor import Descriptor
+from .typed import Typed
+from .broadtypes import *
+from .types import Integer, Float, String, List, Dict
 
 
 def checkattrs(**kwargs):
