@@ -8,7 +8,7 @@ class Stock:
     shares = typetools.Integer()
     price = typetools.MaxSizedInteger(size=100)
     people_buying = typetools.MinSizedInteger(size=0)
-    a = typetools.Mapping()
+    a = typetools.Dict()
 
     def __init__(self, market, shares, price, people_buying, a):
         self.market = market
@@ -20,18 +20,20 @@ class Stock:
 
 @typetools.checkattrs(name=typetools.String(),
                       size=typetools.Integer(),
-                      variations=typetools.List())
+                      variations=typetools.List(),
+                      cost=typetools.typed.GenericTyped(type=float))
 class Font:
-    def __init__(self, name, size, variations):
+    def __init__(self, name, size, variations, cost):
         self.name = name
         self.size = size
         self.variations = variations
+        self.cost = cost
 
 
 class TestTypetools(unittest.TestCase):
     def setUp(self):
         self.stock = Stock("ABC", 13, 56, 14, {"blah": "hah123"})
-        self.arial_font = Font("Arial", 40, ["bold", "italic"])
+        self.arial_font = Font("Arial", 40, ["bold", "italic"], 0.00)
 
     def _change_market_to(self, market):
         self.stock.market = market
@@ -54,6 +56,9 @@ class TestTypetools(unittest.TestCase):
     def _change_variations_to(self, variations):
         self.arial_font.variations = variations
 
+    def _change_cost_to(self, cost):
+        self.arial_font.cost = cost
+
     def test_MaxSizedIterable(self):
         self.assertRaises(ValueError,
                           lambda: self._change_market_to("AAAAAAAAAA"))
@@ -84,6 +89,10 @@ class TestTypetools(unittest.TestCase):
         self.assertRaises(TypeError,
                           lambda: self._change_variations_to("bold and italic"))
 
+    def test_GenericTyped(self):
+        self.assertRaises(TypeError,
+                          lambda: self._change_cost_to("abc123"))
+
 
 if __name__ == "__main__":
     unittest.main()
